@@ -19,20 +19,25 @@ from PyQt6.QtWidgets import (
     QTabWidget,
     QVBoxLayout,
     QWidget,
+    QComboBox,
 )
 
-from smartwheel import common
+from smartwheel import common, config
 
 
 class SettingsWindow(QWidget):
-    def __init__(self, config_file, main_class, conf_class, basedir, parent=None):
+    def __init__(
+        self, config_file, defaults_file, main_class, conf_class, basedir, parent=None
+    ):
         """
         Init SettingsWindow
 
         Parameters
         ==========
         config_file
-            Path to settings registry
+            Path to settings registry config
+        defaults_file
+            Path to settings registry default config
         main_class
             Weakref to RootWindow object
         conf_class
@@ -48,21 +53,24 @@ class SettingsWindow(QWidget):
         self.settings = {}
         self.external_reg = {}
         self.logger = logging.getLogger(__name__)
-        self.loadConfig(config_file)
+        self.loadConfig(config_file, defaults_file)
         self.setConfigHook(main_class, conf_class)
         self.loadSettingsHandlers(
             os.path.join(self.basedir, self.conf["settings_handlers_dir"])
         )
         self.preset_tabs = {}
+        self.preset_controllers = {}
+        self.presets_index_mapping = {}
         self.conf["presets"] = {}
         self.linked_widgets = {}
         self.presets_queue = LifoQueue()
         self.presets_update_queue = []
         self.isLoaded = False
+        self.externalRegistries = {}
 
         self.initLayout()
 
-    def loadConfig(self, config_file):
+    def loadConfig(self, config_file, defaults_file):
         """
         Import settings registry
 
@@ -70,9 +78,17 @@ class SettingsWindow(QWidget):
         ==========
         config_file
             Settings registry config.json file
+        defaults_file
+            Default config file
         """
-        with open(config_file, "r") as f:
-            self.conf = json.load(f)
+        common.app_manager.updateState(common.AppState.SettingsRegistryInit)
+        self.conf = config.Config(
+            config_file=config_file,
+            default_config_file=defaults_file,
+            disableSaving=True,
+        )
+        if not self.conf.loadConfig():
+            os._exit(1)
 
         if self.conf.get("tabs") is not None:
             for i in range(len(self.conf["tabs"])):
@@ -120,10 +136,11 @@ class SettingsWindow(QWidget):
         serial = main_class().serialModules
 
         for name in main_class().serialModulesNames:
+            key = name.split(".")[-1:][0]
             if hasattr(serial[name], "conf"):
-                self.settings["serial"][name] = serial[name].conf
+                self.settings["serial"][key] = serial[name].conf
             else:
-                self.logger.error("serialpipe." + name + " has no conf attribute")
+                self.logger.error("serialpipe." + key + " has no conf attribute")
 
         # Parsing canvas section modules
         self.settings["modules"] = {}
@@ -150,13 +167,15 @@ class SettingsWindow(QWidget):
         handlers_dir
             Directory containing settings handlers, must contain config.json file
         """
+        common.app_manager.updateState(common.AppState.SettingsHandlersInit)
         s_config = os.path.join(handlers_dir, "config.json")
-        if not os.path.exists(s_config):
+        s_default = os.path.join(handlers_dir, "config_defaults.json")
+        self.handlers_conf = config.Config(
+            config_file=s_config, default_config_file=s_default, disableSaving=True
+        )
+        if not self.handlers_conf.loadConfig():
             self.logger.error("Missing " + s_config + " file")
-            os.exit(1)
-
-        with open(s_config, "r") as f:
-            self.handlers_conf = json.load(f)
+            os._exit(1)
 
         self.handlers = {}
         for mod_name in self.handlers_conf["handlers_modules"]:
@@ -293,13 +312,17 @@ class SettingsWindow(QWidget):
         props = prop.split(".")
 
         if self.dictWalk(self.settings[module], props, value, index):
+            name = module + "." + prop
+            if index is not None:
+                name += "." + str(index)
+            self.setCustom(name)
+
             if self.isLoaded:
                 common.config_manager.updated.emit(props[-1:][0])
+                self.main_class().update()
             else:
                 self.presets_update_queue.append(props[-1:][0])
 
-            self.main_class().update()
-
     def savePreset(self, index, name, title, filepath):
         """
         Save the specified preset
@@ -345,20 +368,18 @@ class SettingsWindow(QWidget):
         name
             Preset internal name
         """
+        if not self.isLoaded:
+            self.presets_queue.put((index, name))
+            return
+
         preset = self.conf["presets"][str(index)][name]
 
         for key, value in preset["props"].items():
             p_elem = self.preset_tabs[index].get(key)
             if p_elem is None:
-                if not self.isLoaded:
-                    self.presets_queue.put((index, name))
-                else:
-                    self.logger.warning(
-                        "Could not find "
-                        + key
-                        + " widget from preset "
-                        + preset["title"]
-                    )
+                self.logger.warning(
+                    "Could not find " + key + " widget from preset " + preset["title"]
+                )
                 continue
 
             elem, handler = p_elem
@@ -371,6 +392,22 @@ class SettingsWindow(QWidget):
                     + " widget value from preset "
                     + preset["title"]
                 )
+            #else:
+            #    self.presetValueSet.connect(self.preset_controllers[index]().setCustom)
+
+    def setCustom(self, name):
+        """
+        Set custom preset on settings edit
+
+        Parameters
+        ==========
+        name
+            Internal preset name
+        """
+        index = self.presets_index_mapping.get(name)
+        if index is None:
+            return
+        self.preset_controllers[index]().setCurrentText("Custom")
 
     @pyqtSlot(str)
     def showLinkedWidgets(self, text):
@@ -439,6 +476,9 @@ class SettingsWindow(QWidget):
                 wid.setProperty("index", elem["index"])
                 prop_preset += "." + str(elem["index"])
 
+            if elem["type"] == "preset":
+                self.preset_controllers[index] = weakref.ref(wid.findChild(QComboBox))
+
             if (
                 tab["conf"].get("enable_presets", False)
                 and elem.get("preset", False)
@@ -451,6 +491,8 @@ class SettingsWindow(QWidget):
                     self.handlers[elem["type"]],
                 )
 
+                self.presets_index_mapping[prop_preset] = index
+
             if registriesName is not None:
                 ok = self.handlers[elem["type"]].linkElem(wid, registriesName)
                 if not ok:
@@ -487,6 +529,31 @@ class SettingsWindow(QWidget):
 
         return form.rowCount() - 1, wid
 
+    def initExtraRegistries(self):
+        for reg, value in self.external_reg.items():
+            if value.get("inPlace", False):
+                continue
+
+            scroll = QScrollArea()
+            scroll.setVerticalScrollBarPolicy(Qt.ScrollBarPolicy.ScrollBarAlwaysOn)
+            scroll.setHorizontalScrollBarPolicy(Qt.ScrollBarPolicy.ScrollBarAlwaysOff)
+            scroll.setWidgetResizable(True)
+            wrapper = QWidget()
+            wrapper.setSizePolicy(
+                QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Minimum
+            )
+            form = QFormLayout()
+
+            for elem in value["items"]:
+                tab = {"conf": {"enable_presets": False}}
+                index = None
+                self.processItem(elem, index, form, tab)
+
+            wrapper.setLayout(form)
+            scroll.setWidget(wrapper)
+            scroll.setWindowTitle("Settings")
+            self.externalRegistries[reg] = scroll
+
     def initTab(self, index):
         """
         Parse registry and generate elements
@@ -597,6 +664,9 @@ class SettingsWindow(QWidget):
         """
         Generate layout
         """
+        common.app_manager.updateState(common.AppState.SettingsInit)
+        self.initExtraRegistries()
+
         baseLayout = QVBoxLayout(self)
 
         tabWidget = QTabWidget()
@@ -629,11 +699,12 @@ class SettingsWindow(QWidget):
 
         self.setLayout(baseLayout)
 
+        self.isLoaded = True
+
         while not self.presets_queue.empty():
             self.loadPreset(*self.presets_queue.get())
 
-        self.isLoaded = True
-
         # updating properties
-        if self.presets_update_queue:
+        if not self.presets_update_queue == []:
             common.config_manager.batchUpdate.emit(self.presets_update_queue)
+            self.main_class().update()
