@@ -6,9 +6,10 @@ from smartwheel.ui.internal.baseinternal import BaseInternal
 
 
 class Internal(BaseInternal):
+    name = "kritaAPI"
+    
     def __init__(self, WConfig, config_file):
         super().__init__()
-        self.name = "kritaAPI"
 
     def setColor(self, r, g, b):
         call = {"action": "set_color"}
